@@ -802,36 +802,46 @@ class dataset:
     def point2dict(self,i):
         """returns a dictionary representing one (i-th) data-point
         """
-        return dict(zip(self.vertice_names+map(lambda x: x+"'",self.vertice_names),self.points[i].data[0]))
+	#
+	return dict([(x,self.points[i].data[0][self.get_vertice_by_name(x)]) for x in self.vertice_names])
+        #return dict(zip(self.vertice_names+map(lambda x: x+"'",self.vertice_names),self.points[i].data[0]))
+	
     def get_vertice_by_name(self,name):
         """Returns vertex of self corresponding to the given name
         """
-        return self.vertices[self.vertice_names.index(name)]
+	for v in self.vertices:
+	    if v.name==name:
+		return v
+        #return self.vertices[self.vertice_names.index(name)]
     
-    def get_probs(self,d,cpd,pars):
+    def get_probs(self,d,cpd,pars,transformed=False):
         """returns list of posterior probabilities of all parents being in all possible states.
 
         for discrete variables gives singular distributions, important for continuous vars.
+	if transformef==True then we assume that the dataset is already transformed into probabilities, otherwise apply continuous transformation
         """
         res=[]
         import collections
         for p in pars:
             v=self.get_vertice_by_name(p)
-            if str(d[p]) in v.values:
+            if str(d[p]) in v.values: #discrete?
                 dd=collections.defaultdict(float)
                 dd[d[p]]=1.0
                 res.append(dd) #singular distribution for discrete vars
             else: #continuous vars need care
-                model=continuous.BiNormMeans()
-                model.fromParams(eval(cpd[p]["floatParams"]))
-                x=model.transform([d[p]])[0] # x -> probability of parent being 1
+		if transformed:
+		    x=d[p]
+		else:
+		    model=continuous.BiNormMeans()
+		    model.fromParams(eval(cpd[p]["floatParams"]))
+		    x=model.transform([d[p]])[0] # x -> probability of parent being 1
                 res.append({1:x,0:1-x})
 #        print res
 #        a=b
         return res
                 
             
-    def classify(self, cpd,f,ML=False,prob=None):
+    def classify(self, cpd,f,ML=False,prob=None,transformed=False):
         """
         Output the classification based on the regulators' values from dataset and probabilities from a cpd.
 
@@ -855,7 +865,7 @@ class dataset:
                     total_prob={}
                     for val in c["vals"]:
                         total_prob[int(val)]=0.0
-                    probs=self.get_probs(dicts[i],cpd,c["pars"])
+                    probs=self.get_probs(dicts[i],cpd,c["pars"],transformed=transformed)
                     for possib,poster in c["cpds"].items(): #possible parent values
                         if possib!=None:
                             r=reduce(lambda x,y:x*y,[d[x] for (x,d) in zip(possib,probs)],1)
@@ -866,6 +876,14 @@ class dataset:
                                     pass
                                 
                     ret_d=total_prob
+		    if i==5:
+			#print i,probs,total_prob,c["vals"],dicts[i][c["pars"][0]],c["pars"],self.points[i].data[0][self.get_vertice_by_name(c["pars"][0])]
+			#print self.get_vertice_by_name(c["pars"][0]).index
+			#print dicts[i].items()
+			#print [(self.get_vertice_by_name(x).index,self.points[i].data[0][self.get_vertice_by_name(x)]) for x in self.vertice_names]
+			for v in self.vertices:
+			    #print v.name[:10],v.index,
+			    pass
                     #print ret_d
                     if ML: # Max likelihod
                         f.write("%s\t"%(str(sorted(zip(*reversed(zip(*(ret_d.items())))))[-1][-1]))) # pick the arg max from ret_d
@@ -900,7 +918,7 @@ class dataset:
 #                         else: # output whole posterior
 #                             f.write("%s\t"%(str(ret_d)))
                 f.write("\n")
-    def classify_list(self, cpd,ML=False,prob=None):
+    def classify_list(self, cpd,ML=False,prob=None,transformed=False):
         """
         Output the classification based on the regulators' values from dataset and probabilities from a cpd.
 
@@ -920,7 +938,7 @@ class dataset:
                     total_prob={}
                     for val in c["vals"]:
                         total_prob[int(val)]=0.0
-                    probs=self.get_probs(dicts[i],cpd,c["pars"])
+                    probs=self.get_probs(dicts[i],cpd,c["pars"],transformed=transformed)
                     for possib,poster in c["cpds"].items(): #possible parent values
                         if possib!=None:
                             r=reduce(lambda x,y:x*y,[d[x] for (x,d) in zip(possib,probs)],1)
